@@ -8,17 +8,18 @@
  * Copyright (C) 2002 Sun Microsystems, Inc.
  */
 
-#include <string.h>
+#include "config.h"
+#include "bonobo-a11y.h"
+#include "bonobo-dock-band.h"
+#include "bonobo-dock-item-grip.h"
 #include <glib-object.h>
 #include <atk/atkstateset.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkaccessible.h>
 #include <gtk/gtkbindings.h>
 #include <libgnome/gnome-macros.h>
-#include <bonobo/bonobo-i18n.h>
-#include <bonobo/bonobo-a11y.h>
-#include <bonobo/bonobo-dock-band.h>
-#include <bonobo/bonobo-dock-item-grip.h>
+#include <glib/gi18n.h>
+#include <string.h>
 
 #define DRAG_HANDLE_SIZE 10
 
@@ -48,7 +49,8 @@ bonobo_dock_item_grip_expose (GtkWidget      *widget,
 			  shadow,
 			  clip, widget, "dockitem",
 			  rect->x, rect->y, rect->width, rect->height, 
-			  grip->item->orientation);
+			  (grip->item->orientation == GTK_ORIENTATION_HORIZONTAL)
+			    ? GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL);
 
 	if (GTK_WIDGET_HAS_FOCUS (widget)) {
 		gint focus_width;
@@ -126,6 +128,7 @@ static void
 bonobo_dock_item_grip_dock (BonoboDockItemGrip *grip)
 {
 	BonoboDock *dock;
+	int placement;
 
 	g_return_if_fail (BONOBO_IS_DOCK_ITEM_GRIP (grip));
 
@@ -142,9 +145,15 @@ bonobo_dock_item_grip_dock (BonoboDockItemGrip *grip)
 		GTK_CONTAINER (
 			GTK_WIDGET (grip->item)->parent),
 		GTK_WIDGET (grip->item));
+
+	if (grip->item->orientation == GTK_ORIENTATION_HORIZONTAL)
+		placement = BONOBO_DOCK_TOP;
+	else
+		placement = BONOBO_DOCK_LEFT;
+
 	bonobo_dock_add_item (
 		dock, grip->item,
-		BONOBO_DOCK_TOP, 2, 0, 0, TRUE);
+		placement, 2, 0, 0, TRUE);
 	g_object_unref (G_OBJECT (grip->item));
 }
 
@@ -246,7 +255,7 @@ bonobo_dock_item_grip_get_accessible (GtkWidget *widget)
 		bonobo_a11y_add_actions_interface (
 			a11y_type, &action_if,
 			ACTION_DOCK,   "dock",   _("Dock the toolbar"),    "<Enter>",
-			ACTION_UNDOCK, "undock", _("Un dock the toolbar"), "<Enter>",
+			ACTION_UNDOCK, "undock", _("Undock the toolbar"), "<Enter>",
 			-1);
 	}
 
@@ -266,16 +275,10 @@ bonobo_dock_item_grip_activate (BonoboDockItemGrip *grip)
 		bonobo_dock_item_grip_undock (grip);
 }
 
-static void
-bonobo_dock_item_grip_dispose (GObject *object)
-{
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
-}
-
 static void
 bonobo_dock_item_grip_instance_init (BonoboDockItemGrip *grip)
 {
-/*	GTK_WIDGET_SET_FLAGS (grip, GTK_CAN_FOCUS); */
+	GTK_WIDGET_SET_FLAGS (grip, GTK_CAN_FOCUS); 
 	GTK_WIDGET_SET_FLAGS (grip, GTK_NO_WINDOW);
 }
 
@@ -297,7 +300,7 @@ bonobo_dock_item_grip_key_press_event (GtkWidget   *widget,
   BonoboDockItemGrip *grip = (BonoboDockItemGrip *) widget;
 
   if (!grip->item->is_floating && band &&
-      bonobo_dock_band_handle_key_nav (band, grip->item, event))
+      _bonobo_dock_band_handle_key_nav (band, grip->item, event))
     {
       if (had_focus && !GTK_WIDGET_HAS_FOCUS (widget))
         gtk_widget_grab_focus (widget);
@@ -311,13 +314,10 @@ static void
 bonobo_dock_item_grip_class_init (BonoboDockItemGripClass *klass)
 {
 	GtkBindingSet  *binding_set;
-	GObjectClass   *gobject_class = (GObjectClass *) klass;
 	GtkWidgetClass *widget_class = (GtkWidgetClass *) klass;
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	gobject_class->dispose = bonobo_dock_item_grip_dispose;
-
 	widget_class->expose_event = bonobo_dock_item_grip_expose;
 	widget_class->get_accessible = bonobo_dock_item_grip_get_accessible;
 	widget_class->key_press_event = bonobo_dock_item_grip_key_press_event;
